"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.makeParsedTranslation = exports.xliff2Json = exports.convertXliff2Json = void 0;
const json_file_1 = require("./json-file");
const xliff_file_1 = require("./xliff-file");
async function convertXliff2Json(src, dst) {
    const xliff = await (0, xliff_file_1.loadXliff)(src);
    const json = xliff2Json(xliff);
    (0, json_file_1.saveJson)(json, dst);
}
exports.convertXliff2Json = convertXliff2Json;
function xliff2Json(xliff) {
    const translations = {};
    const template = xliff.resources['ng2.template'];
    Object.keys(template).forEach(key => {
        const target = template[key].target;
        const translation = xliffTranslation2jsonString(target);
        if (translation !== '') {
            translations[key] = translation;
        }
    });
    const json = {
        locale: xliff.targetLanguage,
        translations
    };
    return json;
}
exports.xliff2Json = xliff2Json;
function xliffTranslation2jsonString(xliff) {
    if (xliff === undefined) {
        // translating the empty string (empty source is technically allowed, makes no sense)
        return '';
    }
    if (typeof xliff === 'string') {
        // translation is plain string without interpolation
        return xliff;
    }
    if (!(xliff instanceof Array)) {
        // translation just interpolation (makes no linguistical sense, but technically possible)
        return makeParsedTranslation(['', ''], [xliff.Standalone.id]);
    }
    // makeParsedTranslation expects messagePart0, placeholderName0,
    // messagePart1, placeholderName1, ..., messagePartN. May have to
    // add empty messagePart at front or back.
    const messageParts = [];
    const placeholderNames = [];
    for (const part of xliff) {
        if (typeof part === 'string') {
            messageParts.push(part);
        }
        else {
            // part is placeholder object
            if (messageParts.length === placeholderNames.length) {
                messageParts.push('');
            }
            placeholderNames.push(part.Standalone.id);
        }
    }
    if (messageParts.length === placeholderNames.length) {
        messageParts.push('');
    }
    return makeParsedTranslation(messageParts, placeholderNames);
}
/**
 * Create a `ParsedTranslation` from a set of `messageParts` and `placeholderNames`.
 *
 * Adapted from the function in @angular/localize of the same name
 */
function makeParsedTranslation(messageParts, placeholderNames) {
    if (messageParts.length !== placeholderNames.length + 1) {
        throw new Error('translation part length mismatch');
    }
    let messageString = messageParts[0];
    for (let i = 0; i < placeholderNames.length; i++) {
        messageString += `{$${placeholderNames[i]}}${messageParts[i + 1]}`;
    }
    return messageString;
}
exports.makeParsedTranslation = makeParsedTranslation;
